@@ -6,7 +6,7 @@
 
 #define RAV1E_MAJOR 0
 #define RAV1E_MINOR 3
-#define RAV1E_PATCH 1
+#define RAV1E_PATCH 2
 
 
 #include <stddef.h>
@@ -72,11 +72,11 @@ typedef enum {
     /**
      * BT.470 System M (historical)
      */
-    RA_COLOR_PRIMARIES_BT470_M = 4,
+    RA_COLOR_PRIMARIES_BT470M = 4,
     /**
      * BT.470 System B, G (historical)
      */
-    RA_COLOR_PRIMARIES_BT470_BG,
+    RA_COLOR_PRIMARIES_BT470BG,
     /**
      * BT.601-7 525 (SMPTE 170 M)
      */
@@ -220,7 +220,7 @@ typedef enum {
     /**
      * BT.470 System B, G (historical)
      */
-    RA_MATRIX_COEFFICIENTS_BT470_BG,
+    RA_MATRIX_COEFFICIENTS_BT470BG,
     /**
      * BT.601-7 525 (SMPTE 170 M)
      */
@@ -232,15 +232,15 @@ typedef enum {
     /**
      * YCgCo
      */
-    RA_MATRIX_COEFFICIENTS_YCG_CO,
+    RA_MATRIX_COEFFICIENTS_Y_CG_CO,
     /**
      * BT.2020 non-constant luminance, BT.2100 YCbCr
      */
-    RA_MATRIX_COEFFICIENTS_BT2020_NCL,
+    RA_MATRIX_COEFFICIENTS_BT2020NCL,
     /**
      * BT.2020 constant luminance
      */
-    RA_MATRIX_COEFFICIENTS_BT2020_CL,
+    RA_MATRIX_COEFFICIENTS_BT2020CL,
     /**
      * SMPTE ST 2085 YDzDx
      */
@@ -256,7 +256,7 @@ typedef enum {
     /**
      * BT.2020 ICtCp
      */
-    RA_MATRIX_COEFFICIENTS_ICT_CP,
+    RA_MATRIX_COEFFICIENTS_I_CT_CP,
 } RaMatrixCoefficients;
 
 /**
@@ -292,11 +292,11 @@ typedef enum {
     /**
      * BT.470 System M (historical)
      */
-    RA_TRANSFER_CHARACTERISTICS_BT470_M = 4,
+    RA_TRANSFER_CHARACTERISTICS_BT470M = 4,
     /**
      * BT.470 System B, G (historical)
      */
-    RA_TRANSFER_CHARACTERISTICS_BT470_BG,
+    RA_TRANSFER_CHARACTERISTICS_BT470BG,
     /**
      * BT.601-7 525 (SMPTE 170 M)
      */
